@@ -1,6 +1,10 @@
 # src/tessif/frused/utils.py
 """Tessif (random) utility collection."""
 
+# standard library
+import os
+import sys
+
 
 def greyscale2hex(greyscale, minn=0.0, maxn=1.0):
     """Correlate a number within a certain range to a hex encoded gray value.
@@ -48,3 +52,30 @@ def greyscale2hex(greyscale, minn=0.0, maxn=1.0):
 def _clamp(number, minn, maxn):
     """Clamp number to be within [minn, maxn]."""
     return max(min(maxn, number), minn)
+
+
+class HideStdoutPrinting:
+    """ContextManager for temporarily disabeling printing to stdout.
+
+    Originally written by `Alexander Chzhen
+    <https://stackoverflow.com/a/45669280>`_.
+
+    Examples
+    --------
+    >>> import tessif.write.tools as write_tools
+    >>> with HideStdoutPrinting():
+    ...     print("This will not be printed")
+
+    >>> print("This will be printed as before")
+    This will be printed as before
+    """
+
+    def __enter__(self):
+        """Silence stdout on entering."""
+        self._original_stdout = sys.stdout
+        sys.stdout = open(os.devnull, "w")
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        """Unsilence stdout on entering."""
+        sys.stdout.close()
+        sys.stdout = self._original_stdout
